![super](./docs/imgs/isalive.png)

# isalive
isalive is a small python script with no external dependencies
that runs a simple telegram bot to notify the status of http resources


# howto whatfgfcvcvcvn


## todo
* [ ] interactive config.json creation
* [ ] ~~colorful output~~ (maybe never)
* [ ] ability to set headers (globals and locals for resource), set url params, set timeout
* [ ] write pretty README.md
